# Beta version 0.51

- Vastly improved performances
- Fixed many bugs, improved errors display
- Improved mobile layout/display
- Display tournament winner deck
- Display rating points in standings
- Automatically drop players who did not show up
- Additional filters on tournaments list
- Player can now see the deck they uploaded
- Allow attribution on decklist upload
- Leagues: league of leagues and pure score ranking (finals excluded)
- Updated tournament rules
- New default PLANNED state for tournaments: registration need to be opened
- Automatically close past tournaments
- Add V5 format (no decklist check yet)
- Organizers can download a clean tournament report text file

# Alpha version 0.46

- Full tournament management capability
- Members management
- VEKN sync
- VEKN roles and permissions


